package com.gqy.web.controller.document;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.gqy.common.core.domain.AjaxResult;
import com.gqy.common.core.domain.AjaxResultCQY;
import com.gqy.common.utils.StringUtils;
import com.gqy.document.domain.TemplateCategory;
import com.gqy.document.domain.vo.PageResult;
import com.gqy.document.service.ITemplateCategoryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;

/**
 * 文档目录代码
 */
@RestController
@RequestMapping("/template/category")
public class TemplateCategoryController {

    @Autowired
    private ITemplateCategoryService templateCategoryService;


    /**
     * 创建模板分类
     */
//    @PreAuthorize("@ss.hasPermi('system:category:add')")
    @PostMapping("/create")
    public AjaxResultCQY create(@RequestBody TemplateCategory templateCategory) {
        return templateCategoryService.create(templateCategory);
    }





    /**
     * 模板树查询
     * @return
     */
    @PostMapping("/treeCategory")
    public AjaxResultCQY treeCategory(){

        return templateCategoryService.treeCategory();
    }



    /**
     *
     * @param request
     * @return
     */
    @PostMapping("/search")
    public AjaxResultCQY search(HttpServletRequest request) {
        // 获取表单参数
        String name = request.getParameter("name");
        String status = request.getParameter("status");
        String parent_id = request.getParameter("parent_id");
        String page = request.getParameter("page");
        String page_size = request.getParameter("pageSize");
        // 参数转换
        String parentId = StringUtils.isNotEmpty(parent_id) ? parent_id : "0";
        Integer statusInt = StringUtils.isNotEmpty(status) ? Integer.valueOf(status) : null;
        Integer pageNum = StringUtils.isNotEmpty(page) ? Integer.valueOf(page) : 1;
        Integer pageSize = StringUtils.isNotEmpty(page_size) ? Integer.valueOf(page_size) : 10;

        // 判断是否为顶级分类查询
        if ("0".equals(parentId)) {
            // 分页查询顶级分类
            PageHelper.startPage(pageNum, pageSize);
            List<TemplateCategory> list = templateCategoryService.selectTopCategoryList(name, statusInt);

            // 查询子分类数量
            for (TemplateCategory category : list) {
                int childCount = templateCategoryService.selectChildCount(category.getId());
                category.setChild_count(childCount);
            }
            PageInfo<TemplateCategory> pageInfo = new PageInfo<>(list);

            // 4. 封装并返回结果
            PageResult PageResult=  new PageResult(
                    pageInfo.getPageNum(),
                    pageInfo.getPageSize(),
                    pageInfo.getPages(),
                    pageInfo.getTotal(),
                    pageInfo.getList());

            return AjaxResultCQY.success("查询成功", PageResult);
        }else{
            // 直接查询子分类列表
            List<TemplateCategory> list = templateCategoryService.selectChildCategoryList(parentId);

            // 查询子分类数量
            for (TemplateCategory category : list) {
                int childCount = templateCategoryService.selectChildCount(category.getId());
                category.setChild_count(childCount);
            }

            return AjaxResultCQY.success("查询成功", list);
        }


    }

    /**
     * 获取模板分类信息
     *
     * @return 返回结果对象，成功则包含模板分类信息
     */
    @PostMapping("/info")
//    @PreAuthorize("@ss.hasPermi('system:category:query')")
    public AjaxResultCQY info(@RequestBody Map maps)
    {
        String id = maps.get("id").toString();
        return templateCategoryService.selectTemplateCategoryById(Long.valueOf(id));
    }

}
