package com.gqy.framework.config;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONFactory;
import com.alibaba.fastjson2.JSONReader;
import com.alibaba.fastjson2.JSONWriter;
import com.alibaba.fastjson2.reader.ObjectReaderProvider;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.redis.serializer.RedisSerializer;
import org.springframework.data.redis.serializer.SerializationException;

import java.nio.charset.StandardCharsets;


/**
 * Redis使用FastJson序列化
 *
 * @author raycos
 */

public class FastJson2JsonRedisSerializer<T> implements RedisSerializer<T> {
//    private static final Logger log = LoggerFactory.getLogger(FastJson2JsonRedisSerializer.class);
    private Class<T> clazz;

    public FastJson2JsonRedisSerializer(Class<T> clazz) {
        super();
        this.clazz = clazz;
    }

    @Override
    public byte[] serialize(T t) throws SerializationException {
        if (t == null) {
            return new byte[0];
        }
        try {
            return JSON.toJSONBytes(t,
                    JSONWriter.Feature.WriteClassName,
                    JSONWriter.Feature.FieldBased,
                    JSONWriter.Feature.WriteMapNullValue,
                    JSONWriter.Feature.WriteNulls
            );
        } catch (Exception ex) {
            throw new SerializationException("Could not serialize: " + ex.getMessage(), ex);
        }
    }

    @Override
    public T deserialize(byte[] bytes) throws SerializationException {
        if (bytes == null || bytes.length <= 0) {
            return null;
        }

        try {
            // 获取当前线程的类加载器
            ClassLoader contextClassLoader = Thread.currentThread().getContextClassLoader();

            // 创建 ObjectReaderProvider
            ObjectReaderProvider provider = new ObjectReaderProvider();
            provider.addAutoTypeAccept("com.gqy.*");

            // 创建 JSONReader 并配置
            String jsonString = new String(bytes, StandardCharsets.UTF_8);
            JSONReader jsonReader = JSONReader.of(jsonString);

            // 配置 Context
            JSONReader.Context context = JSONFactory.createReadContext(provider);
            context.config(
                    JSONReader.Feature.SupportAutoType,
                    JSONReader.Feature.FieldBased,
                    JSONReader.Feature.UseNativeObject
            );

            // 使用配置好的 context 创建新的 JSONReader
            jsonReader = JSONReader.of(jsonString, context);

            // 执行反序列化
            return jsonReader.read(clazz);

        } catch (Exception ex) {
            throw new SerializationException("Could not deserialize: " + ex.getMessage(), ex);
        }
    }
}
