package com.gqy.document.service.impl;

import com.gqy.common.core.domain.AjaxResult;
import com.gqy.common.core.domain.AjaxResultCQY;
import com.gqy.document.domain.DcParams;
import com.gqy.document.service.IDcParamsService;
import com.gqy.system.mapper.DcParamsMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 参数配置管理 控制层
 *
 *
 */
@Service
public class DcParamsServiceImpl implements IDcParamsService {

    @Autowired
    private DcParamsMapper dcParamsMapper;



    /**
     * 查询参数列表
     *
     * @param params 查询参数
     * @return 分页结果
     */
    public List<DcParams> search(DcParams params) {
        return dcParamsMapper.selectParamsList(params);
    }

    /**
     * 新增参数配置
     *
     * @param params 参数配置信息
     * @return 结果
     */
    public AjaxResultCQY create(DcParams params) {

        // 校验参数名称是否唯一
        if (dcParamsMapper.checkNameUnique(params.getName()) != null)
        {
            return AjaxResultCQY.error("参数名称'" + params.getName() + "'已存在");
        }

        try {
            // 设置默认值
            if (params.getStatus() == null)
            {
                params.setStatus(5); // 默认使用中
            }
            if (params.getValue_type() == null)
            {
                params.setValue_type(1); // 默认输入框类型
            }
            if (params.getType() == null)
            {
                params.setType(1); // 默认变量类型
            }

            // 插入数据
            int rows = dcParamsMapper.insertParams(params);
            return rows > 0 ? AjaxResultCQY.success("新增成功") : AjaxResultCQY.error("新增失败");
        }
        catch (Exception e)
        {
            return AjaxResultCQY.error("新增参数失败：" + e.getMessage());
        }

    }

    /**
     * 根据ID查询参数配置
     *
     * @param id 参数ID
     * @return 参数配置信息
     */
    public AjaxResultCQY info(Long id) {
        return AjaxResultCQY.success("查询成功",dcParamsMapper.selectParamsById(id)) ;
    }


    /**
     * 修改参数配置
     *
     * @param params 参数配置信息
     * @return 结果
     */
    @Transactional
    public AjaxResultCQY update(DcParams params)
    {
        try {
            // 校验是否存在
            if (params.getId() == null)
            {
                return AjaxResultCQY.error("参数ID不能为空");
            }

            // 校验参数名称是否唯一
            if (dcParamsMapper.checkNameUnique(params.getName()) != null)
            {
                return AjaxResultCQY.error("参数名称'" + params.getName() + "'已存在");
            }

            // 更新数据
            int rows = dcParamsMapper.updateParams(params);
            if (rows > 0)
            {
                return AjaxResultCQY.success("修改成功");
            }
            return AjaxResultCQY.error("修改参数配置失败，请联系管理员");
        }
        catch (Exception e)
        {
            return AjaxResultCQY.error("修改参数配置失败：" + e.getMessage());
        }
    }

}
