package com.gqy.document.service.impl;

import com.gqy.common.annotation.Log;
import com.gqy.common.enums.UserStatus;

import com.gqy.common.utils.bean.BeanUtils;
import com.gqy.document.domain.DcPsParam;
import com.gqy.document.domain.DcSpec;
import com.gqy.document.mapper.DcSpecMapper;
import com.gqy.document.service.IDcSpecService;
import com.gqy.system.mapper.DcPsParamMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 产品规格Service业务层处理
 */
@Service
public class DcSpecServiceImpl implements IDcSpecService {

    @Autowired
    private DcSpecMapper dcSpecMapper;

    @Autowired
    private DcPsParamMapper dcPsParamMapper;

    /**
     * 查询列表
     * @param params
     * @return
     */
    public List<Map<String, Object>> selectDcPsParamAndSpec(Map<String, Object> params){
        return  dcPsParamMapper.selectDcPsParamAndSpec(params);
    }



    /**
     * 删除规格信息
     * @param id
     * @return
     */
    public int deleteDcPsParam(Integer id){
        try{
            DcSpec queryDcSpec = dcSpecMapper.selectDcSpecById(id);
            String ps_no = queryDcSpec.getPs_no();
            dcSpecMapper.deleteDcSpecById(id);
            dcPsParamMapper.deleteDcPsParamByPspMode(ps_no);
            return 1;
        }catch (Exception e){
            e.printStackTrace();
        }
        return 0;
    }



    /**
     * 查询产品规格
     */
    public DcSpec selectDcSpecById(Integer psId) {
        return dcSpecMapper.selectDcSpecById(psId);
    }


    /**
     * 查询产品规格列表
     */
    public List<DcSpec> selectDcSpecList(DcSpec dcSpec) {
        return dcSpecMapper.selectDcSpecList(dcSpec);
    }

    /**
     * 保存规格信息
     * @param dcSpec
     * @return
     */
    public int insertDcSpec(DcSpec dcSpec) {
        return dcSpecMapper.insertDcSpec(dcSpec);
    }

    /**
     * 保存规格参数 包括 规格参数值
     * @param maps
     * @return
     */
    public int insertDcSpecParam(Map maps) {
        try {
            //保存规格信息表
            DcSpec dcSpec = new DcSpec();
            String ps_no = maps.get("ps_no").toString();
//            dcSpec.setPs_no(ps_no);
//            dcSpec.setPs_name(maps.get("ps_name").toString());
//         //   dcSpec.setPs_status(Integer.valueOf(UserStatus.OK.getCode()));
//            dcSpec.setPs_category(maps.get("ps_category").toString());

            BeanUtils.mapToBean(maps,dcSpec );

            dcSpecMapper.insertDcSpec(dcSpec);

            //规格参数
            DcPsParam dcPsParam = new DcPsParam();
//            dcPsParam.setPsp_mode(ps_no);
//            String psp_name = maps.get("psp_name").toString();
//            dcPsParam.setPsp_name(psp_name);
//            String psp_value = maps.get("psp_value").toString();
//            dcPsParam.setPsp_value(psp_value);

            BeanUtils.mapToBean(maps,dcPsParam );
            dcPsParam.setPsp_mode(ps_no);

            dcPsParamMapper.insertDcPsParam(dcPsParam);

            return  1;
        }catch (Exception e){
            e.printStackTrace();
        }
        return 0;
    }



    /**
     * 更新规格信息
     * @param maps
     * @return
     */
    public int updateDcSpecMaps(Map maps){
        try{
            String ps_id = maps.get("ps_id").toString();
            DcSpec dcSpecQuery = dcSpecMapper.selectDcSpecById(Integer.valueOf(ps_id));
            //Object dest, Object src
            BeanUtils.copyBeanProp(dcSpecQuery,maps);
            dcSpecMapper.updateDcSpec(dcSpecQuery);

            String ps_no = maps.get("ps_no").toString();
            DcPsParam dcPsParamQuery = new DcPsParam();
            dcPsParamQuery.setPsp_mode(ps_no);
            List<DcPsParam> listDcPsParam =  dcPsParamMapper.selectDcPsParamList(dcPsParamQuery);
            DcPsParam dcPsParam = listDcPsParam.get(0);
            BeanUtils.copyBeanProp(dcPsParam, maps);


            dcPsParamMapper.updateDcPsParam(dcPsParam);
            return 1;
        }catch (Exception e){
            e.printStackTrace();
        }
        return 0;
    }


}
