package com.gqy.document.service.impl;

import com.gqy.common.core.domain.AjaxResult;
import com.gqy.common.enums.UserStatus;
import com.gqy.common.utils.SecurityUtils;
import com.gqy.document.domain.DcSystem;
import com.gqy.document.domain.DcWork;
import com.gqy.document.mapper.DcSystemMapper;
import com.gqy.document.service.IDcSystemService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.List;

@Service
public class DcSystemServiceImpl implements IDcSystemService {

    private static final Logger log = LoggerFactory.getLogger(DcSystemServiceImpl.class);

    @Autowired
    DcSystemMapper dcSystemMapper;

    /**
     * 新增系统配置
     */
    public AjaxResult insertDcSystem(DcSystem dcSystem) {
        try{
            dcSystem.setSysStatus(Integer.valueOf(UserStatus.OK.getCode()));
            dcSystemMapper.insertDcSystem(dcSystem);
        }catch (Exception e){
            log.info("error===insertDcSystem",e);
            return AjaxResult.error("系统异常");
        }
        return AjaxResult.success("新增系统配置成功");
    }

    /**
     * 新增系统配置
     */
    public AjaxResult updateDcSystem(DcSystem dcSystem) {
        try{
            dcSystemMapper.updateDcSystem(dcSystem);
        }catch (Exception e){
            log.info("error===updateDcSystem",e);
            return AjaxResult.error("系统异常");
        }
        return AjaxResult.success("新增系统配置成功");
    }

    /**
     * 删除系统
     * @param Long id
     * @return
     */
    public AjaxResult deleteDcSystem(Long id) {
        DcSystem dcsystem = dcSystemMapper.selectDcSystemById(id);
        if(dcsystem != null){
            dcsystem.setSysStatus(Integer.valueOf(UserStatus.DELETED.getCode()));
        }
        return updateDcSystem(dcsystem);
    }


    /**
     * 查询列表信息
     * @param dcSystem
     * @return
     */
    public List<DcSystem> selectDcSystemList(DcSystem dcSystem) {
        dcSystem.setSysStatus(0);
        return  dcSystemMapper.selectDcSystemList(dcSystem);
    }


}
