package com.gqy.document.service.impl;

import com.gqy.common.core.domain.AjaxResult;
import com.gqy.common.core.domain.AjaxResultCQY;
import com.gqy.common.utils.DateUtils;
import com.gqy.document.domain.TemplateCategory;
import com.gqy.document.mapper.TemplateCategoryMapper;
import com.gqy.document.service.ITemplateCategoryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class TemplateCategoryServiceImpl  implements ITemplateCategoryService {

    @Autowired
    private TemplateCategoryMapper templateCategoryMapper;

    /**
     * 查询顶级分类列表
     */
    public List<TemplateCategory> selectTopCategoryList(String name, Integer status) {
        return templateCategoryMapper.selectTopCategoryList(name, status);
    }

    /**
     * 查询子分类列表
     */
    public List<TemplateCategory> selectChildCategoryList(String parentId) {
        return templateCategoryMapper.selectChildCategoryList(parentId);
    }

    /**
     * 查询子分类数量
     */
    public int selectChildCount(Integer categoryId) {
        return templateCategoryMapper.selectChildCount(categoryId);
    }

    /**
     * 获取分类树结构
     */
    public AjaxResultCQY treeCategory() {
        List<TemplateCategory> allCategories = templateCategoryMapper.selectTemplateCategoryList();
        // 2. 构建树形结构，从顶级分类(parent_id=0)开始
        List<Map<String, Object>> treeData = buildTree(allCategories, "0");
        // 3. 返回成功结果
        return AjaxResultCQY.success(treeData);
    }


    /**
     * 创建模板分类
     *
     * @param templateCategory 模板分类信息
     * @return 结果
     */
    @Transactional
    public AjaxResultCQY create(TemplateCategory templateCategory) {
        try {
            // 设置默认值
            templateCategory.setStatus(5);
            templateCategory.setCreate_time(DateUtils.getNowDate());
            // templateCategory.setUpdate_time(DateUtils.getNowDate());
            // 保存数据
            templateCategoryMapper.insertTemplateCategory(templateCategory);
            return  AjaxResultCQY.success("新增成功");
        }catch (Exception e){
            return  AjaxResultCQY.error(e.getMessage());
        }
    }

    /**
     * 查询模板分类信息
     *
     * @param id 模板分类ID
     * @return 返回结果对象，成功则包含模板分类信息
     */
    public AjaxResultCQY selectTemplateCategoryById(Long id) {
       return AjaxResultCQY.success("查询成功",templateCategoryMapper.selectTemplateCategoryById(id));
    }


    /**
     * 递归构建树形结构
     *
     * @param categories 所有分类列表
     * @param parentId 父级ID
     * @return 树形结构数据
     */
    private List<Map<String, Object>> buildTree(List<TemplateCategory> categories, String parentId) {
        return categories.stream()
                .filter(category -> category.getParent_id().equals(parentId))
                .map(category -> {
                    // 构建当前节点
                    Map<String, Object> node = new HashMap<>();
                    node.put("id", category.getId());
                    node.put("name", category.getName());

                    // 递归构建子节点
                    List<Map<String, Object>> children = buildTree(categories, String.valueOf(category.getId()));
                    node.put("children", children);

                    return node;
                })
                .collect(Collectors.toList());
    }

}
