package com.gqy.document.service.impl;

import com.gqy.common.enums.UserStatus;
import com.gqy.common.utils.DateUtils;
import com.gqy.document.domain.DcWork;
import com.gqy.document.mapper.WorkMapper;
import com.gqy.document.service.IWorkService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class WorkServiceImpl implements IWorkService {

    @Autowired
    private WorkMapper workMapper;

    /**
     * 查询工程列表
     *
     * @param work 工程信息查询条件
     * @return 工程信息集合
     */
    public List<DcWork> selectWorkList(DcWork work) {
        return workMapper.selectWorkList(work);
    }

    /**
     * 查询工程详细信息
     *
     * @param wkId 工程主键
     * @return 工程信息
     */
    public DcWork selectWorkById(Long wkId) {
        return workMapper.selectWorkById(wkId);
    }

    /**
     * 新增工程
     *
     * @param work 工程信息
     * @return 结果
     */

    public int insertWork(DcWork work) {
        // 如果状态为空，设置默认值为0（显示）
        if (work.getWkStaus() == null) {
            work.setWkStaus(0);
        }

        // 如果产品数为空，设置默认值为0
        if (work.getWkProductCount() == null) {
            work.setWkProductCount(0);
        }

        // 设置创建时间
       // work.setCreateTime(DateUtils.getNowDate());

        return workMapper.insertWork(work);
    }

    /**
     * 修改工程
     *
     * @param work 工程信息
     * @return 结果
     */
    public int updateWork(DcWork work) {


        return workMapper.updateWork(work);
    }

    /**
     * 删除工程id
     * @param id
     * @return
     */
    public int deleWork(Long id) {
        DcWork work = workMapper.selectWorkById(id);
        if(work != null){
            work.setWkStaus(Integer.valueOf(UserStatus.DELETED.getCode()));
        }
        return updateWork(work);
    }

}
